@@ -304,6 +304,12 @@ extern int fut_reset( unsigned int keymask, unsigned int threadid );
 extern int fut_getbuffer( int *nints, unsigned long **buffer );
 
 extern int fut_header( unsigned long head, ... );
+
+/* activate the recording of thread id */
+extern void fut_enable_tid_logging();
+
+/* disactivate the recording of thread id */
+extern void fut_disable_tid_logging();
 #endif
 
 
