@@ -237,7 +237,7 @@ static void get_symbolsfd( fxt_t fxt, FILE *fd, fxt_symbol_source source, unsign
 	
 	for(;;i++)
 		{
-		fprintf(stderr,"\r%d",i);
+		//fprintf(stderr,"\r%d",i);
 		if( !(name = malloc(MAXNAMELEN)) )
 			{
 			fprintf(stderr,"couldn't allocate memory for name\n");
@@ -251,7 +251,7 @@ static void get_symbolsfd( fxt_t fxt, FILE *fd, fxt_symbol_source source, unsign
 			|| (n > 0 && len<=1 && (type=name[0],
 					n = fscanf(fd, "%s%n", name, &len)) == EOF ) )
 			{/* end of file, stop */
-			fprintf(stderr," done\n");
+			//fprintf(stderr," done\n");
 			return;
 			}
 
@@ -358,7 +358,7 @@ void fxt_get_symbols( fxt_t fxt, const char *file, fxt_symbol_source source, uns
 	{
 	FILE *fd;
 	if( !file ) return;
-	fprintf(stderr,"opening %s\n", file);
+	//fprintf(stderr,"opening %s\n", file);
 	if( (fd = fopen(file, "r")) < 0 )
 		{
 		fprintf(stderr,"opening %s\n",file);
@@ -400,7 +400,7 @@ int fxt_record_symbols( fxt_t fxt, int fd )
 
 int fxt_load_symbols( fxt_t fxt, int fd )
 	{
-	static int i;
+	//static int i;
 	struct address_entry	*entry;
 	char *name;
 restart:
